"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var sql = require("mssql");
var log4js = require("log4js");
var mssql_config_1 = require("../config/mssql.config");
var auth_mssql_1 = require("./mssql/auth.mssql");
var domain_mssql_1 = require("./mssql/domain.mssql");
var account_mssql_1 = require("./mssql/account.mssql");
var accountBalance_mssql_1 = require("./mssql/accountBalance.mssql");
var accountSubAccountVCCSummaryTransaction_mssql_1 = require("./mssql/accountSubAccountVCCSummaryTransaction.mssql");
var accountSubAccountVCCDetailedTransaction_mssql_1 = require("./mssql/accountSubAccountVCCDetailedTransaction.mssql");
var accountVcc_mssql_1 = require("./mssql/accountVcc.mssql");
var accountVccBalance_mssql_1 = require("./mssql/accountVccBalance.mssql");
var apiUser_mssql_1 = require("./mssql/apiUser.mssql");
var currency_mssql_1 = require("./mssql/currency.mssql");
var vcc_mssql_1 = require("./mssql/vcc.mssql");
var home_mssql_1 = require("./mssql/home.mssql");
var notification_mssql_1 = require("./mssql/notification.mssql");
var role_mssql_1 = require("./mssql/role.mssql");
var user_mssql_1 = require("./mssql/user.mssql");
var platform_mssql_1 = require("./mssql/platform.mssql");
var platformData_mssql_1 = require("./mssql/platformData.mssql");
var platformLicense_mssql_1 = require("./mssql/platformLicense.mssql");
var integration_mssql_1 = require("./mssql/integration.mssql");
var license_mssql_1 = require("./mssql/license.mssql");
var client_mssql_1 = require("./mssql/client.mssql");
var report_mssql_1 = require("./mssql/report.mssql");
var logger = log4js.getLogger('Sql');
function MsSqlInit(app) {
    return new Promise(function (resolve, reject) {
        logger.info('Iniciando conexión a base de datos \'' + mssql_config_1.MSSQL_CONFIG.server + '\'');
        console.log('Iniciando conexión a base de datos \'' + mssql_config_1.MSSQL_CONFIG.server + '\'');
        var sqlConn = new sql.Connection(mssql_config_1.MSSQL_CONFIG, function (err) {
            if (err) {
                var errMsg = (typeof err === 'string' ? err : err.message || err.description || 'Error al ejecutar solicitud');
                logger.error('No se pudo establecer conexion a base de datos: ' + errMsg);
                console.error('No se pudo establecer conexion a base de datos: ' + errMsg);
                reject(err);
            }
            else {
                logger.info('Conexión a base de datos establecida');
                console.log('Conexión a base de datos establecida');
                resolve(true);
            }
        });
        app.set('sqlConn', sqlConn);
        account_mssql_1.AccountMSSql(app);
        accountBalance_mssql_1.AccountBalanceMSSql(app);
        accountSubAccountVCCSummaryTransaction_mssql_1.AccountSubAccountVCCSummaryTransactionMSSql(app);
        accountSubAccountVCCDetailedTransaction_mssql_1.AccountSubAccountVCCDetailTransactionMSSql(app);
        accountVcc_mssql_1.AccountVccMSSql(app);
        accountVccBalance_mssql_1.AccountVccBalanceMSSql(app);
        auth_mssql_1.AuthMSSql(app);
        apiUser_mssql_1.ApiUserMSSql(app);
        currency_mssql_1.CurrencyMSSql(app);
        domain_mssql_1.DomainMSSql(app);
        vcc_mssql_1.VCCMSSql(app);
        home_mssql_1.HomeMSSql(app);
        notification_mssql_1.NotificationMSSql(app);
        role_mssql_1.RoleMSSql(app);
        user_mssql_1.UserMSSql(app);
        platform_mssql_1.PlatformMSSql(app);
        platformData_mssql_1.PlatformDataMSSql(app);
        platformLicense_mssql_1.PlatformLicenseMSSql(app);
        license_mssql_1.LicenseMSSql(app);
        integration_mssql_1.IntegrationMSSql(app);
        client_mssql_1.ClientMSSql(app);
        report_mssql_1.ReportMSSql(app);
    });
}
exports.MsSqlInit = MsSqlInit;
