"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var log4js = require("log4js");
var sql = require('mssql');
var logger = log4js.getLogger('Sql');
var sqlConn;
function AccountVccMSSql(app) {
    sqlConn = app.get('sqlConn');
}
exports.AccountVccMSSql = AccountVccMSSql;
function CreateAccountVCC(platformHash, installationId, accountId, subAccountId, accountVcc, transcriptionRatePerHour, transcriptionRatePerSecond, semanticAnalysisRatePerTransaction, cognitiveAnalysisRatePerTransaction, asignableBalance, product, user) {
    return new sql.Request(sqlConn)
        .input('PlatformHash', sql.VarChar(100), platformHash)
        .input('InstallationId', sql.VarChar(50), installationId)
        .input('AccountId', sql.VarChar(50), accountId)
        .input('SubAccountId', sql.VarChar(50), subAccountId)
        .input('AccountVCC', sql.VarChar(50), accountVcc)
        .input('TranscriptionRatePerHour', sql.Decimal(18, 5), transcriptionRatePerHour)
        .input('TranscriptionRatePerSecond', sql.Decimal(18, 5), transcriptionRatePerSecond)
        .input('SemanticAnalysisRatePerTransaction', sql.Decimal(18, 5), semanticAnalysisRatePerTransaction)
        .input('CognitiveAnalysisRatePerTransaction', sql.Decimal(18, 5), cognitiveAnalysisRatePerTransaction)
        .input('VCCBalance', sql.Decimal(18, 5), asignableBalance)
        .input('Product', sql.VarChar(250), product)
        .input('USER', sql.VarChar(50), user)
        .execute('CreateAccountVCC')
        .then(function (recordsets) {
        logger.info('[accountVCC.mssql::CreateAccountVCC] Result: ', recordsets);
        var recordset = (recordsets && recordsets.length > 0 ? recordsets[0] : null);
        var output = (recordset && recordset.length > 0 ? recordset[0] : null);
        return Promise.resolve(output && output.result === 1);
    }).catch(function (err) {
        var errorMsg = (err && err.procName ? 'Error al ejecutar \'' + err.procName + '\': ' : 'Error al ejecutar consulta: ') + (err ? typeof err === 'string' ? err : err.message || err.description || '' : '');
        logger.error(errorMsg);
        return Promise.reject(err);
    });
}
exports.CreateAccountVCC = CreateAccountVCC;
function GetAccountVCC(installationId, vcc) {
    return new sql.Request(sqlConn)
        .input('InstallationId', sql.VarChar(100), installationId)
        .input('VCC', sql.VarChar(50), vcc)
        .execute('GetAccountVCC')
        .then(function (recordsets) {
        logger.info('[accountVCC.mssql::GetAccountVCC] Result: ', recordsets.length);
        var recordset = (recordsets && recordsets.length > 0 ? recordsets[0] : null);
        var output = (recordset && recordset.length > 0 ? recordset[0] : null);
        return Promise.resolve(output);
    })
        .catch(function (err) {
        var errorMsg = (err && err.procName ? 'Error al ejecutar \'' + err.procName + '\': ' : 'Error al ejecutar consulta: ') + (err ? typeof err === 'string' ? err : err.message || err.description || '' : '');
        logger.error(errorMsg);
        return Promise.reject(err);
    });
}
exports.GetAccountVCC = GetAccountVCC;
function GetAccountVccByAccountVcc(installationId, accountId, vcc) {
    return new sql.Request(sqlConn)
        .input('InstallationId', sql.VarChar(50), installationId)
        .input('AccountId', sql.VarChar(50), accountId)
        .input('Vcc', sql.VarChar(50), vcc)
        .execute('GetAccountVccByAccountVcc')
        .then(function (recordsets) {
        var recordset = (recordsets && recordsets.length > 0 ? recordsets[0] : null);
        var output = (recordset && recordset.length > 0 ? recordset[0] : null);
        return Promise.resolve(output && output.result === 1);
    }).catch(function (err) {
        var errorMsg = (err && err.procName ? 'Error al ejecutar \'' + err.procName + '\': ' : 'Error al ejecutar consulta: ') + (err ? typeof err === 'string' ? err : err.message || err.description || '' : '');
        logger.error(errorMsg);
        return Promise.reject(err);
    });
}
exports.GetAccountVccByAccountVcc = GetAccountVccByAccountVcc;
function GetAccountVccByAccountSubAccountVcc(installationId, accountId, subAccountId) {
    return new sql.Request(sqlConn)
        .input('InstallationId', sql.VarChar(50), installationId)
        .input('AccountId', sql.VarChar(50), accountId)
        .input('SubAccountId', sql.VarChar(50), subAccountId)
        .execute('GetAccountVccByAccountSubAccountVcc')
        .then(function (recordsets) {
        var recordset = (recordsets && recordsets.length > 0 ? recordsets[0] : null);
        var output = (recordset && recordset.length > 0 ? recordset[0] : null);
        return Promise.resolve(output && output.result === 1);
    }).catch(function (err) {
        var errorMsg = (err && err.procName ? 'Error al ejecutar \'' + err.procName + '\': ' : 'Error al ejecutar consulta: ') + (err ? typeof err === 'string' ? err : err.message || err.description || '' : '');
        logger.error(errorMsg);
        return Promise.reject(err);
    });
}
exports.GetAccountVccByAccountSubAccountVcc = GetAccountVccByAccountSubAccountVcc;
function GetAccountVccRates(installationId, vcc, processId) {
    return new sql.Request(sqlConn)
        .input('InstallationId', sql.VarChar(50), installationId)
        .input('Vcc', sql.VarChar(50), vcc)
        .input('ProcessId', sql.VarChar(50), processId)
        .execute('GetAccountVccRates')
        .then(function (recordsets) {
        var recordset = (recordsets && recordsets.length > 0 ? recordsets[0] : null);
        var output = (recordset && recordset.length > 0 ? recordset[0] : null);
        return Promise.resolve(output);
    }).catch(function (err) {
        var errorMsg = (err && err.procName ? 'Error al ejecutar \'' + err.procName + '\': ' : 'Error al ejecutar consulta: ') + (err ? typeof err === 'string' ? err : err.message || err.description || '' : '');
        logger.error(errorMsg);
        return Promise.reject(err);
    });
}
exports.GetAccountVccRates = GetAccountVccRates;
function GetAccountVccProducts(installationId, vcc) {
    return new sql.Request(sqlConn)
        .input('InstallationId', sql.VarChar(50), installationId)
        .input('Vcc', sql.VarChar(50), vcc)
        .execute('GetAccountVccProducts')
        .then(function (recordsets) {
        var recordset = (recordsets && recordsets.length > 0 ? recordsets[0] : null);
        return Promise.resolve(recordset);
    }).catch(function (err) {
        var errorMsg = (err && err.procName ? 'Error al ejecutar \'' + err.procName + '\': ' : 'Error al ejecutar consulta: ') + (err ? typeof err === 'string' ? err : err.message || err.description || '' : '');
        logger.error(errorMsg);
        return Promise.reject(err);
    });
}
exports.GetAccountVccProducts = GetAccountVccProducts;
function GetVCCsByAccount(installationId, accountId, type) {
    return new sql.Request(sqlConn)
        .input('InstallationId', sql.VarChar(50), installationId)
        .input('AccountId', sql.VarChar(50), accountId)
        .input('Type', sql.VarChar(20), type)
        .execute('GetVCCsByAccount')
        .then(function (recordsets) {
        var recordset = (recordsets && recordsets.length > 0 ? recordsets[0] : null);
        return Promise.resolve(recordset);
    }).catch(function (err) {
        var errorMsg = (err && err.procName ? 'Error al ejecutar \'' + err.procName + '\': ' : 'Error al ejecutar consulta: ') + (err ? typeof err === 'string' ? err : err.message || err.description || '' : '');
        logger.error(errorMsg);
        return Promise.reject(err);
    });
}
exports.GetVCCsByAccount = GetVCCsByAccount;
