"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var log4js = require("log4js");
var sql = require('mssql');
var logger = log4js.getLogger('Sql');
var sqlConn;
function ApiUserMSSql(app) {
    sqlConn = app.get('sqlConn');
}
exports.ApiUserMSSql = ApiUserMSSql;
function GetApiUsers(vcc, search_criteria, search_expression) {
    return new sql.Request(sqlConn)
        .input('SearchCriteria', sql.VarChar(50), search_criteria)
        .input('SearchExpression', sql.VarChar(50), search_expression)
        .input('VCC', sql.VarChar(50), vcc)
        .execute('GetApiUsers')
        .then(function (recordsets) {
        var recordset = (recordsets && recordsets.length > 0 ? recordsets[0] : null);
        return Promise.resolve(recordset);
    }).catch(function (err) {
        var errorMsg = (err && err.procName ? 'Error al ejecutar \'' + err.procName + '\': ' : 'Error al ejecutar consulta: ') + (err ? typeof err === 'string' ? err : err.message || err.description || '' : '');
        logger.error(errorMsg);
        return Promise.reject(err);
    });
}
exports.GetApiUsers = GetApiUsers;
function ValidateApiUser(installationId, vcc, apiUser, pin, user) {
    return new sql.Request(sqlConn)
        .input('InstallationId', sql.VarChar(50), installationId)
        .input('VCC', sql.VarChar(50), vcc)
        .input('apiUser', sql.VarChar(50), apiUser)
        .input('Pin', sql.VarChar(250), pin)
        .input('User', sql.VarChar(50), user)
        .execute('ValidateApiUser')
        .then(function (recordsets) {
        var recordset = (recordsets && recordsets.length > 0 ? recordsets[0] : null);
        var output = (recordset && recordset.length > 0 ? recordset[0] : null);
        return Promise.resolve(output && output.result === 1);
    }).catch(function (err) {
        var errorMsg = (err && err.procName ? 'Error al ejecutar \'' + err.procName + '\': ' : 'Error al ejecutar consulta: ') + (err ? typeof err === 'string' ? err : err.message || err.description || '' : '');
        logger.error(errorMsg);
        return Promise.reject(err);
    });
}
exports.ValidateApiUser = ValidateApiUser;
function GetApiUser(vcc, user) {
    return new sql.Request(sqlConn)
        .input('UserApi', sql.VarChar(50), user)
        .input('VCC', sql.VarChar(50), vcc)
        .execute('GetApiUser')
        .then(function (recordsets) {
        var recordset = (recordsets && recordsets.length > 0 ? recordsets[0] : null);
        var user = (recordset && recordset.length > 0 ? recordset[0] : null);
        return Promise.resolve(user);
    }).catch(function (err) {
        var errorMsg = (err && err.procName ? 'Error al ejecutar \'' + err.procName + '\': ' : 'Error al ejecutar consulta: ') + (err ? typeof err === 'string' ? err : err.message || err.description || '' : '');
        logger.error(errorMsg);
        return Promise.reject(err);
    });
}
exports.GetApiUser = GetApiUser;
function SaveApiUser(apiUser) {
    return new sql.Request(sqlConn)
        .input('InstallationId', sql.VarChar(100), apiUser.installationId)
        .input('VCC', sql.VarChar(50), apiUser.vcc)
        .input('Pin', sql.VarChar(250), apiUser.pin)
        .input('UserApi', sql.VarChar(50), apiUser.userApi)
        .input('FailedTry', sql.Int, apiUser.failedTry)
        .input('IsLocked', sql.Bit, apiUser.isLocked)
        .input('CreatedDate', sql.DateTime, apiUser.createdDate)
        .input('CreatedByUserId', sql.VarChar(50), apiUser.createdByUserId)
        .input('CreatedByRemoteUser', sql.Bit, apiUser.createdByRemoteUser)
        .input('LastModifiedDate', sql.DateTime, apiUser.lastModifiedDate)
        .input('LastModifiedByUserId', sql.VarChar(50), apiUser.lastModifiedByUserId)
        .input('LastModifiedByRemoteUser', sql.Bit, apiUser.lastModifiedByRemoteUser)
        .execute('SaveApiUser')
        .then(function (recordsets) {
        var recordset = (recordsets && recordsets.length > 0 ? recordsets[0] : null);
        var output = (recordset && recordset.length > 0 ? recordset[0] : null);
        return Promise.resolve(output && output.result === 1);
    }).catch(function (err) {
        var errorMsg = (err && err.procName ? 'Error al ejecutar \'' + err.procName + '\': ' : 'Error al ejecutar consulta: ') + (err ? typeof err === 'string' ? err : err.message || err.description || '' : '');
        logger.error(errorMsg);
        return Promise.reject(err);
    });
}
exports.SaveApiUser = SaveApiUser;
function DeleteApiUser(vcc, user) {
    return new sql.Request(sqlConn)
        .input('VCC', sql.VarChar(50), vcc)
        .input('User', sql.VarChar(50), user)
        .execute('DeleteApiUser')
        .then(function (recordsets) {
        var recordset = (recordsets && recordsets.length > 0 ? recordsets[0] : null);
        var output = (recordset && recordset.length > 0 ? recordset[0] : null);
        return Promise.resolve(output && output.result === 1);
    }).catch(function (err) {
        var errorMsg = (err && err.procName ? 'Error al ejecutar \'' + err.procName + '\': ' : 'Error al ejecutar consulta: ') + (err ? typeof err === 'string' ? err : err.message || err.description || '' : '');
        logger.error(errorMsg);
        return Promise.reject(err);
    });
}
exports.DeleteApiUser = DeleteApiUser;
