"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var moment = require("moment");
var log4js = require("log4js");
var mssql_service_1 = require("../db/mssql.service");
var promises_shared_1 = require("../shared/promises.shared");
var logger = log4js.getLogger('ServerScripts');
function BatchService(app) {
    app.post('/api/batch/search_batch_id', function (req, res, next) {
        var platformHash = req.headers['platform-hash'];
        var batch = req.body.batch;
        var installationId = null;
        logger.info('[BatchService::search_batch_id] Received ' + req.method + ' on \'' + req.path + '\'');
        var genericResult = {};
        promises_shared_1.DummyPromise()
            .then(function (result) {
            if (platformHash && batch) {
                return mssql_service_1.MSSql.GetPlatformByHash(platformHash);
            }
            else {
                logger.info('[BatchService::search_batch_id] Received params: ', platformHash, batch);
                throw 'SERVER_ERROR_MISSING_SEARCH_PARAMETERS';
            }
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_PLATFORM_NOT_FOUND';
            else {
                installationId = result.installationId;
                return mssql_service_1.MSSql.GetAccountSubAccountVCCBatchSummaryByBatchTypeId(platformHash, installationId, batch.vcc, batch.batchTypeName, batch.batchTypeId);
            }
        })
            .then(function (result) {
            if (res.headersSent)
                return;
            if (result && result.length) {
                genericResult.status = true;
                genericResult.description = 'OK';
                genericResult.data = result;
            }
            else {
                genericResult.status = false;
                genericResult.description = 'SERVER_ERROR_REQUEST_ERROR';
            }
            res.json(genericResult);
        })
            .catch(function (err) {
            var clientMsg = (typeof err === 'string' ? err : 'CANNOT_PROCESS_REQUEST');
            var errorMsg = (typeof err === 'string' ? err : err.message || err.description || 'SERVER_ERROR_REQUESTING_ERROR');
            logger.error('[BatchService::close_batch_summary] Error on \'' + req.path + '\': ' + errorMsg);
            if (res.headersSent)
                return;
            genericResult.status = false;
            genericResult.description = clientMsg;
            genericResult.error = errorMsg;
            res.json(genericResult);
        });
    });
    app.post('/api/batch/save_batch_summary', function (req, res, next) {
        var platformHash = req.body.platformHash;
        var batch = req.body.batch;
        var logLabel = '[BatchService::save_batch_summary] [platformHash::installationId => ' + platformHash + '::' + batch.installationId + '] ';
        logger.info(logLabel + 'Received ' + req.method + ' on \'' + req.path + '\'');
        promises_shared_1.DummyPromise()
            .then(function (result) {
            if (platformHash && batch) {
                return mssql_service_1.MSSql.GetPlatformByHash(platformHash);
            }
            else {
                logger.info(logLabel + 'Received params: ', platformHash, batch);
                throw 'SERVER_ERROR_MISSING_SEARCH_PARAMETERS';
            }
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_PLATFORM_NOT_FOUND';
            else
                return mssql_service_1.MSSql.GetAccountVCC(batch.installationId, batch.vcc);
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_VCC_NOT_FOUND';
            else
                return mssql_service_1.MSSql.AccountSubAccountVCCBatchSummaryCreate(platformHash, batch.installationId, result.accountId, result.subAccountId, batch.vcc, batch.totalInteraction, batch.totalAsync, batch.totalAsyncDetail, batch.totalTextPhrases, batch.alreadyTextPhrases, batch.rawChar, batch.validChar, batch.inProcessAsyncDetail, batch.inProcessRawChar, batch.alreadyTranscribedAsyncDetail, batch.alreadyTranscribedRawChar, batch.alreadyTranscribedValidChar, batch.totalSync, batch.totalAudio, batch.totalCallPhrases, batch.alreadyCallPhrases, batch.durationTime, batch.roundedTime, batch.inProcessAudio, batch.inProcessDurationTime, batch.alreadyTranscribedAudio, batch.alreadyDurationTime, batch.alreadyRoundedDurationTime, batch.alreadyTranscribedDurationTime, batch.alreadyTranscribedRoundedDurationTime, batch.totalQueries, batch.totalModels, batch.modelRequests, batch.batchTypeName, batch.batchTypeId, batch.processId, batch.templateId, batch.userApi, moment(batch.startDate).toDate());
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_BATCH_SUMMARY_SAVING_FAILED';
            else {
                if (res.headersSent)
                    return;
                logger.info(logLabel + 'Batch summary saving succed');
                res.json({ status: true, description: 'OK', data: result });
            }
        })
            .catch(function (err) {
            var clientMsg = (typeof err === 'string' ? err : 'CANNOT_PROCESS_REQUEST');
            var errorMsg = (typeof err === 'string' ? err : err.message || err.description || 'SERVER_ERROR_REQUESTING_ERROR');
            logger.error(logLabel + 'Error on \'' + req.path + '\': ' + errorMsg);
            if (res.headersSent)
                return;
            res.json({ status: false, description: clientMsg, error: errorMsg });
        });
    });
    app.post('/api/batch/update_batch_summary', function (req, res, next) {
    });
    app.post('/api/batch/cancel_batch_summary', function (req, res, next) {
        var platformHash = req.headers['platform-hash'];
        var installationId = null;
        var account = null;
        var batch = req.body.batchManage;
        var genericResult = {};
        logger.info('[BatchService::cancel_batch_summary] Received ' + req.method + ' on \'' + req.path + '\'');
        promises_shared_1.DummyPromise()
            .then(function (result) {
            if (platformHash) {
                return mssql_service_1.MSSql.GetPlatformByHash(platformHash);
            }
            else {
                logger.info('[BatchService::resume_batch_summary] Received params: ', platformHash);
                throw 'SERVER_ERROR_MISSING_SEARCH_PARAMETERS';
            }
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_PLATFORM_NOT_FOUND';
            else {
                installationId = result.installationId;
                return mssql_service_1.MSSql.GetAccountVCC(installationId, batch.vcc);
            }
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_VCC_NOT_FOUND';
            account = result;
            return mssql_service_1.MSSql.GetAccountSubAccountVCCBatchSummaryId(platformHash, installationId, batch.vcc, batch.batchTypeName, batch.batchTypeId);
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_BATCH_NOT_FOUND';
            batch.status = 'CANCELLED_BY_USER';
            return mssql_service_1.MSSql.SaveAccountSubAccountVCCBatchSummaryTransactionStatus(platformHash, installationId, account.accountId, account.subAccountId, batch.vcc, result.batchId, batch.systemService, batch.status, batch.user);
        })
            .then(function (result) {
            if (res.headersSent)
                return;
            if (result) {
                genericResult.status = true;
                genericResult.description = 'OK';
                genericResult.data = result;
                res.json(genericResult);
            }
            else {
                throw 'SERVER_ERROR_REQUEST_FAILED';
            }
        })
            .catch(function (err) {
            var clientMsg = (typeof err === 'string' ? err : 'CANNOT_PROCESS_REQUEST');
            var errorMsg = (typeof err === 'string' ? err : err.message || err.description || 'SERVER_ERROR_REQUESTING_ERROR');
            logger.error('[BatchService::cancel_batch_summary] Error on \'' + req.path + '\': ' + errorMsg);
            if (res.headersSent)
                return;
            genericResult.status = false;
            genericResult.description = clientMsg;
            genericResult.error = errorMsg;
            res.json(genericResult);
        });
    });
    app.post('/api/batch/close_batch_summary', function (req, res, next) {
        var platformHash = req.headers['platform-hash'];
        var batch = req.body.batch;
        var installationId = null;
        logger.info('[BatchService::close_batch_summary] Received ' + req.method + ' on \'' + req.path + '\'');
        promises_shared_1.DummyPromise()
            .then(function (result) {
            if (platformHash && batch) {
                return mssql_service_1.MSSql.GetPlatformByHash(platformHash);
            }
            else {
                logger.info('[BatchService::close_batch_summary] Received params: ', platformHash, batch);
                throw 'SERVER_ERROR_MISSING_SEARCH_PARAMETERS';
            }
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_PLATFORM_NOT_FOUND';
            else {
                installationId = result.installationId;
                return mssql_service_1.MSSql.GetAccountVCC(installationId, batch.vcc);
            }
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_VCC_NOT_FOUND';
            else
                return mssql_service_1.MSSql.GetAccountSubAccountVCCBatchSummaryId(platformHash, installationId, batch.vcc, batch.batchTypeName, batch.batchTypeId);
        })
            .then(function (result) {
            if (result && result.batchId) {
                batch.batchId = result.batchId;
                return mssql_service_1.MSSql.AccountSubAccountVCCBatchSummaryClose(result.batchId, moment(batch.closedDate).toDate());
            }
            else {
                return Promise.resolve(false);
            }
        })
            .then(function (result) {
            if (res.headersSent)
                return;
            res.json({ status: true, description: 'OK', data: { result: result, batch: batch } });
        })
            .catch(function (err) {
            var clientMsg = (typeof err === 'string' ? err : 'CANNOT_PROCESS_REQUEST');
            var errorMsg = (typeof err === 'string' ? err : err.message || err.description || 'SERVER_ERROR_REQUESTING_ERROR');
            logger.error('[BatchService::close_batch_summary] Error on \'' + req.path + '\': ' + errorMsg);
            if (res.headersSent)
                return;
            res.json({ status: false, description: clientMsg, error: errorMsg });
        });
    });
    app.post('/api/batch/resume_batch_summary', function (req, res, next) {
        var platformHash = req.headers['platform-hash'];
        var logLabel = '[BatchService::resume_batch_summary] [platformHash => ' + platformHash + '] ';
        var installationId = null;
        var account = null;
        var batch = req.body.batchManage;
        var genericResult = {};
        logger.info(logLabel + 'Received ' + req.method + ' on \'' + req.path + '\'');
        promises_shared_1.DummyPromise()
            .then(function (result) {
            if (platformHash) {
                return mssql_service_1.MSSql.GetPlatformByHash(platformHash);
            }
            else {
                logger.info(logLabel + 'Received params: ', platformHash);
                throw 'SERVER_ERROR_MISSING_SEARCH_PARAMETERS';
            }
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_PLATFORM_NOT_FOUND';
            else {
                installationId = result.installationId;
                return mssql_service_1.MSSql.GetAccountVCC(installationId, batch.vcc);
            }
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_VCC_NOT_FOUND';
            account = result;
            return mssql_service_1.MSSql.GetAccountSubAccountVCCBatchSummaryId(platformHash, installationId, batch.vcc, batch.batchTypeName, batch.batchTypeId);
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_BATCH_NOT_FOUND';
            batch.status = 'RUNNING';
            return mssql_service_1.MSSql.SaveAccountSubAccountVCCBatchSummaryTransactionStatus(platformHash, installationId, account.accountId, account.subAccountId, batch.vcc, result.batchId, batch.systemService, batch.status, batch.user);
        })
            .then(function (result) {
            if (res.headersSent)
                return;
            if (result) {
                genericResult.status = true;
                genericResult.description = 'OK';
                genericResult.data = result;
                res.json(genericResult);
            }
            else {
                throw 'SERVER_ERROR_REQUEST_FAILED';
            }
        })
            .catch(function (err) {
            var clientMsg = (typeof err === 'string' ? err : 'CANNOT_PROCESS_REQUEST');
            var errorMsg = (typeof err === 'string' ? err : err.message || err.description || 'SERVER_ERROR_REQUESTING_ERROR');
            logger.error('[BatchService::resume_batch_summary] Error on \'' + req.path + '\': ' + errorMsg);
            if (res.headersSent)
                return;
            genericResult.status = false;
            genericResult.description = clientMsg;
            genericResult.error = errorMsg;
            res.json(genericResult);
        });
    });
    app.post('/api/batch/save_batch_detail', function (req, res, next) {
        var platformHash = req.headers['platform-hash'];
        var rawData = req.body.data;
        var fileName = req.body.file;
        var fileNameArr = fileName.split('-');
        var installationId = req.body.installationId;
        var dataTotal = rawData.split('\n');
        var data = dataTotal.filter(function (d) { return d.length > 0; });
        logger.info('[BatchService::save_batch_detail] Received ' + req.method + ' on \'' + req.path + '\'');
        promises_shared_1.DummyPromise()
            .then(function (result) {
            if (fileNameArr && fileNameArr.length >= 2 && data && platformHash && data) {
                return mssql_service_1.MSSql.GetPlatformByHash(platformHash);
            }
            else {
                logger.info('[BatchService::save_batch_detail] Received params: ', platformHash, data);
                throw 'SERVER_ERROR_MISSING_SEARCH_PARAMETERS';
            }
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_PLATFORM_NOT_FOUND';
            switch (fileNameArr[1]) {
                case 'NEW.txt':
                    return mssql_service_1.MSSql.AccountSubAccountVCCBulkNewBatchDetail(platformHash, installationId, 'accountId', 'subAccountId', data);
                case 'UPDATE.txt':
                    return mssql_service_1.MSSql.AccountSubAccountVCCBulkUpdateBatchDetail(platformHash, installationId, 'accountId', 'subAccountId', data);
                case 'COMPLETED.txt':
                    return mssql_service_1.MSSql.AccountSubAccountVCCBulkCloseBatchDetail(platformHash, installationId, 'accountId', 'subAccountId', data);
                default:
                    logger.info('[BatchService::save_batch_detail] Operation: ' + fileNameArr[1]);
                    throw 'SERVER_ERROR_UNKNOW_OPERATION';
            }
        })
            .then(function (result) {
            if (res.headersSent)
                return;
            res.json({ status: true, description: 'OK', data: fileName });
        })
            .catch(function (err) {
            var clientMsg = (typeof err === 'string' ? err : 'CANNOT_PROCESS_REQUEST');
            var errorMsg = (typeof err === 'string' ? err : err.message || err.description || 'SERVER_ERROR_REQUESTING_ERROR');
            logger.error('[BatchService::save_batch_detail] Error on \'' + req.path + '\': ' + errorMsg);
            if (res.headersSent)
                return;
            res.json({ status: false, description: clientMsg, error: errorMsg });
        });
    });
    app.post('/api/batch/get_current_batches', function (req, res, next) {
        var platformHash = req.headers['platform-hash'];
        var installationId = null;
        var rawData = req.body.data;
        var genericResult = {};
        logger.info('[BatchService::save_batch_detail] Received ' + req.method + ' on \'' + req.path + '\'');
        promises_shared_1.DummyPromise()
            .then(function (result) {
            if (platformHash) {
                return mssql_service_1.MSSql.GetPlatformByHash(platformHash);
            }
            else {
                logger.info('[BatchService::get_current_batches] Received params: ', platformHash);
                throw 'SERVER_ERROR_MISSING_SEARCH_PARAMETERS';
            }
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_PLATFORM_NOT_FOUND';
            installationId = result.installationId;
            var promiseArray = [];
            promiseArray.push(mssql_service_1.MSSql.GetPlatformCurrentBatches(platformHash, installationId));
            promiseArray.push(mssql_service_1.MSSql.GetPlatformCancelledBatches(platformHash, installationId));
            return Promise.all(promiseArray);
        })
            .then(function (result) {
            if (result) {
                var cancelledBatches = [];
                if (result[1] && result[1].batches && result[1].batches.length > 0) {
                    cancelledBatches = result[1].batches;
                }
                if (result[0] && result[0].batches && result[0].batches.length > 0) {
                    if (result[0].balance !== null) {
                        var promiseArray_1 = [];
                        var allowedBatchesResult_1 = [];
                        var pausedBatchesResult_1 = [];
                        result[0].batches.map(function (b) {
                            if (b.Status === 'CREATED' || b.Status === 'RUNNING' || b.Status.includes('CANCELLED')) {
                                var balance = result[0].balance.find(function (r) { return r.AccountId === b.AccountId && r.SubAccountId === b.SubAccountId && r.VCC === b.VCC && r.SystemService === b.SystemService; });
                                if (balance) {
                                    if ((b.RATED ? b.RATED : 0) > b.RETAINED
                                        &&
                                            (b.RATED - b.RETAINED) > balance.AvailableBalance
                                        &&
                                            !b.Status.includes('CANCELLED')) {
                                        b.ALLOWED = false;
                                        switch (b.SystemService) {
                                            case 'TRANSCRIPTION':
                                                b.Status = 'PAUSED_BY_INSUFFICIENT_TRANSCRIPTION_BALANCE';
                                                break;
                                            case 'SEMANTIC_ANALYSIS':
                                                b.Status = 'PAUSED_BY_INSUFFICIENT_SEMANTIC_ANALYSIS_BALANCE';
                                                break;
                                            case 'COGNITIVE_ANALYSIS':
                                                b.Status = 'PAUSED_BY_INSUFFICIENT_COGNITIVE_ANALYSIS_BALANCE';
                                                break;
                                        }
                                        pausedBatchesResult_1.push(b);
                                        promiseArray_1.push(mssql_service_1.MSSql.SaveAccountSubAccountVCCBatchSummaryTransactionStatus(platformHash, installationId, b.AccountId, b.SubAccountId, b.VCC, b.BatchId, b.SystemService, b.Status, 'system'));
                                    }
                                    else {
                                        b.ALLOWED = true;
                                        balance.AvailableBalance = balance.AvailableBalance - (b.RATED ? b.RATED : 0);
                                        allowedBatchesResult_1.push(b);
                                    }
                                }
                                else {
                                    logger.info('[BatchService::get_current_batches] Balance not found, data: ', b);
                                }
                            }
                        });
                        genericResult.status = true;
                        genericResult.description = 'OK';
                        genericResult.data = {
                            allowedBatches: allowedBatchesResult_1,
                            cancelledBatches: cancelledBatches
                        };
                        if (pausedBatchesResult_1.length > 0) {
                            return Promise.all(promiseArray_1);
                        }
                        else {
                            return Promise.resolve([true]);
                        }
                    }
                    else {
                        throw 'SERVER_ERROR_PLATFORM_BALANCES_NOT_FOUND';
                    }
                }
                else {
                    throw 'SERVER_ERROR_CURRENT_BATCHES_NOT_FOUND';
                }
            }
            else {
                throw 'SERVER_ERROR_REQUEST_FAILED';
            }
        })
            .then(function (result) {
            return mssql_service_1.MSSql.CloseCancelledBatches(installationId);
        })
            .then(function (result) {
            if (res.headersSent)
                return;
            res.json(genericResult);
        })
            .catch(function (err) {
            var clientMsg = (typeof err === 'string' ? err : 'CANNOT_PROCESS_REQUEST');
            var errorMsg = (typeof err === 'string' ? err : err.message || err.description || 'SERVER_ERROR_REQUESTING_ERROR');
            logger.error('[BatchService::save_batch_detail] Error on \'' + req.path + '\': ' + errorMsg);
            if (res.headersSent)
                return;
            genericResult.status = false;
            genericResult.description = clientMsg;
            genericResult.error = errorMsg;
            res.json(genericResult);
        });
    });
    app.post('/api/batch/get_batch_balance_detail', function (req, res, next) {
        var platformHash = req.headers['platform-hash'];
        var installationId = null;
        var batch = req.body.batchDetail;
        var genericResult = {};
        logger.info('[BatchService::get_batch_balance_detail] Received ' + req.method + ' on \'' + req.path + '\'');
        promises_shared_1.DummyPromise()
            .then(function (result) {
            if (platformHash) {
                return mssql_service_1.MSSql.GetPlatformByHash(platformHash);
            }
            else {
                logger.info('[BatchService::get_batch_balance_detail] Received params: ', platformHash);
                throw 'SERVER_ERROR_MISSING_SEARCH_PARAMETERS';
            }
        })
            .then(function (result) {
            if (result === null)
                throw 'SERVER_ERROR_PLATFORM_NOT_FOUND';
            installationId = result.installationId;
            return mssql_service_1.MSSql.GetBatchBalanceDetail(platformHash, installationId, batch.vcc, batch.batchTypeName, batch.batchTypeId);
        })
            .then(function (result) {
            if (res.headersSent)
                return;
            if (result) {
                genericResult.status = true;
                genericResult.description = 'OK';
                genericResult.data = result;
                res.json(genericResult);
            }
            else {
                throw 'SERVER_ERROR_REQUEST_FAILED';
            }
        })
            .catch(function (err) {
            var clientMsg = (typeof err === 'string' ? err : 'CANNOT_PROCESS_REQUEST');
            var errorMsg = (typeof err === 'string' ? err : err.message || err.description || 'SERVER_ERROR_REQUESTING_ERROR');
            logger.error('[BatchService::get_batch_balance_detail] Error on \'' + req.path + '\': ' + errorMsg);
            if (res.headersSent)
                return;
            genericResult.status = false;
            genericResult.description = clientMsg;
            genericResult.error = errorMsg;
            res.json(genericResult);
        });
    });
}
exports.BatchService = BatchService;
